@@ -2,7 +2,7 @@
 # -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
 #   Catfish - a versatile file searching tool
 #   Copyright (C) 2007-2012 Christian Dywan <christian@twotoasts.de>
-#   Copyright (C) 2012-2016 Sean Davis <smd.seandavis@gmail.com>
+#   Copyright (C) 2012-2019 Sean Davis <bluesabre@xfce.org>
 #
 #   This program is free software: you can redistribute it and/or modify it
 #   under the terms of the GNU General Public License version 2, as published
@@ -14,7 +14,7 @@
 #   PURPOSE.  See the GNU General Public License for more details.
 #
 #   You should have received a copy of the GNU General Public License along
-#   with this program.  If not, see <http://www.gnu.org/licenses/>.
+#   with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 from gi.repository import Gtk, GdkPixbuf
 import os
@@ -32,9 +32,9 @@ def check_gtk_version(major_version, minor_version, micro=0):
     """Return true if running gtk >= requested version"""
     return gtk_version >= (major_version, minor_version, micro)
 
+
 # Check if the LANG variable needs to be set
 use_env = False
-use_pkexec = False
 
 
 def check_dependencies(commands=[]):
@@ -46,7 +46,6 @@ def check_dependencies(commands=[]):
 
     # Check for sudo or pkexec
     if pexpect.which("pkexec") is not None:
-        use_pkexec = True
         return True
 
     if pexpect.which("sudo") is None:
@@ -74,7 +73,7 @@ def check_dependencies(commands=[]):
             # User not in sudoers
             return False
 
-    except:
+    except Exception:
         # Something else went wrong.
         child.close()
 
